@@ -22,7 +22,7 @@ datatype = st.sampled_from([pd.Series, np.array, list])
 
 feature_data = st.sampled_from(["ensembl_gtf", "gencode_gtf", "ucsc_bed"])
 
-chromosomes = st.sampled_from(["chr{}".format(str(e)) for e in list(range(1, 23)) + "X Y M".split()])
+chromosomes = st.sampled_from([f"chr{e!s}" for e in list(range(1, 23)) + "X Y M".split()])
 chromosomes_small = st.sampled_from(["chr1"])
 cs = st.one_of(chromosomes, chromosomes_small)
 
@@ -106,18 +106,16 @@ def dfs_min2(draw):  # nosec
     # if not strand:
     #     df = df.drop("Strand", axis=1)
 
-    gr = PyRanges(df, int64=True)
+    return PyRanges(df)
     # gr = PyRanges(df)
 
     # do not sort like this, use pyranges sort
     # np.random.seed(draw(st.integers(min_value=0, max_value=int(1e6))))
     # gr.df = df.reindex(np.random.permutation(df.index.values))
 
-    return gr
-
 
 @st.composite
-def dfs_min(draw):  # nosec
+def dfs_min(draw):
     df = draw(better_dfs_min)
     # strand = draw(use_strand)
     df.loc[:, "End"] += df.Start
@@ -125,23 +123,8 @@ def dfs_min(draw):  # nosec
     df.insert(3, "Name", "a")
     df.insert(4, "Score", 0)
 
-    # df.Start = df.Start.astype(np.int32)
-    # df.End = df.End.astype(np.int32)
-    # print(df.dtypes)
-    # stranded = draw(st.booleans())
-    # if not strand:
-    #     df = df.drop("Strand", axis=1)
-
-    gr = PyRanges(df, int64=True)
-    # print(gr)
-    # raise
-    # gr = PyRanges(df)
-
-    # do not sort like this, use pyranges sort
-    # np.random.seed(draw(st.integers(min_value=0, max_value=int(1e6))))
-    # gr.df = df.reindex(np.random.permutation(df.index.values))
-
-    return gr
+    print(df)
+    return PyRanges(df)
 
 
 @st.composite
@@ -157,15 +140,13 @@ def dfs_no_min(draw):  # nosec
     # if not strand:
     #     df = df.drop("Strand", axis=1)
 
-    gr = PyRanges(df, int64=True)
+    return PyRanges(df)
     # gr = PyRanges(df)
 
     # do not sort like this, use pyranges sort
     # np.random.seed(draw(st.integers(min_value=0, max_value=int(1e6))))
     # gr.df = df.reindex(np.random.permutation(df.index.values))
 
-    return gr
-
 
 @st.composite
 def dfs_min_with_id(draw):  # nosec
@@ -185,7 +166,7 @@ def dfs_min_with_id(draw):  # nosec
     # if not strand:
     #     df = df.drop("Strand", axis=1)
 
-    gr = PyRanges(df)
+    return PyRanges(df)
     # print(gr)
     # raise
     # gr = PyRanges(df)
@@ -194,8 +175,6 @@ def dfs_min_with_id(draw):  # nosec
     # np.random.seed(draw(st.integers(min_value=0, max_value=int(1e6))))
     # gr.df = df.reindex(np.random.permutation(df.index.values))
 
-    return gr
-
 
 @st.composite
 def dfs_min_with_gene_id(draw):  # nosec
@@ -216,7 +195,7 @@ def dfs_min_with_gene_id(draw):  # nosec
     # if not strand:
     #     df = df.drop("Strand", axis=1)
 
-    gr = PyRanges(df)
+    return PyRanges(df)
     # print(gr)
     # raise
     # gr = PyRanges(df)
@@ -225,8 +204,6 @@ def dfs_min_with_gene_id(draw):  # nosec
     # np.random.seed(draw(st.integers(min_value=0, max_value=int(1e6))))
     # gr.df = df.reindex(np.random.permutation(df.index.values))
 
-    return gr
-
 
 @st.composite
 def df_data(draw):
@@ -260,15 +237,13 @@ def dfs_min_single_chromosome(draw):
 def genomicfeature(draw):
     dataset_name = draw(feature_data)
     print("dataset name " * 5, dataset_name)
-    dataset = getattr(pr.data, dataset_name)()
+    dataset = getattr(pr.example_data, dataset_name)()
     dataset = dataset[dataset.Feature.isin(["gene", "transcript", "exon"])]
 
     # subsetter = draw(arrays(np.bool, shape=len(dataset)))
     gene_ids = list(dataset.gene_id.drop_duplicates())
     genes = draw(st.lists(st.sampled_from(gene_ids), unique="True", min_size=1))
-    dataset = dataset[dataset.gene_id.isin(genes)]
-
-    return dataset
+    return dataset[dataset.gene_id.isin(genes)]
 
 
 @st.composite
